from setuptools import setup

setup(name='Bigauss_probability_distribution',
      version='0.1',
      description='Binomial and Gaussian distributions',
      packages=['Bigauss_probability_distribution'],
      author = 'Abhishek Chaturvedi',
      zip_safe=False)
